@@ -13,7 +13,7 @@ class TestGreatExpectations(TestCase):
             expectation_suite=my_expectation_suite
         )
         validation_results = my_df.validate()
-        return validation_results
+        assert validation_results['success']
 
         #val = GreatExepectationsValidator()
         #val.set_expectations("/Users/stevefrensch/dev/streamduo-python-sdk/tests/test_schemas/car_expectations.json")
